#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # Example with re2
# 
# *wrapclib* wraps the library [re2](https://github.com/google/re2) using the wrapper [pyre2](https://github.com/facebook/pyre2).

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[2]:


from wrapclib import re2


# ## Example with HTML

# In[3]:


import re
s = "<h1>mot</h1>"
print(re.compile("(<.*>)").match(s).groups())


# In[4]:


s = "<h1>mot</h1>"
print(re2.compile("(<.*>)").match(s).groups())


# ## Group, Span

# In[5]:


s = """date 0 : 14/9/2000
date 1 : 20/04/1971     date 2 : 14/09/1913     date 3 : 2/3/1978
date 4 : 1/7/1986     date 5 : 7/3/47     date 6 : 15/10/1914
date 7 : 08/03/1941     date 8 : 8/1/1980     date 9 : 30/6/1976"""

expression = re2.compile(
    "([0-3]?[0-9]/[0-1]?[0-9]/([0-2][0-9])?[0-9][0-9])[^\d]")
expression.search(s).group(1, 2)


# In[6]:


c = expression.search(s).span(1)
s[c[0]:c[1]]


# ## Names

# In[7]:


date = "05/22/2010"
exp = "(?P<jj>[0-9]{1,2})/(?P<mm>[0-9]{1,2})/(?P<aa>((19)|(20))[0-9]{2})"
com = re2.compile(exp)
print(com.search(date).groupdict())


# ## findall
# 
# *findall* is not natively implemented in *re2*. It was added.

# In[8]:


s = """date 0 : 14/9/2000
date 1 : 20/04/1971     date 2 : 14/09/1913     date 3 : 2/3/1978
date 4 : 1/7/1986     date 5 : 7/3/47     date 6 : 15/10/1914
date 7 : 08/03/1941     date 8 : 8/1/1980     date 9 : 30/6/1976"""

expression = re2.compile(
    "([0-3]?[0-9]/[0-1]?[0-9]/([0-2][0-9])?[0-9][0-9])[^\d]")

re2.findall(expression, s)


# ## benchmark

# In[9]:


s = """date 0 : 14/9/2000
date 1 : 20/04/1971     date 2 : 14/09/1913     date 3 : 2/3/1978
date 4 : 1/7/1986     date 5 : 7/3/47     date 6 : 15/10/1914
date 7 : 08/03/1941     date 8 : 8/1/1980     date 9 : 30/6/1976"""

expression = re.compile(
    "([0-3]?[0-9]/[0-1]?[0-9]/([0-2][0-9])?[0-9][0-9])[^\d]")

get_ipython().run_line_magic('timeit', 'expression.findall(s)')


# In[10]:


get_ipython().run_line_magic('timeit', 're2.findall(expression, s)')


# That's expected as method *findall* is implemented in python and not C.

# In[11]: